import quippy
from ase.lattice.cubic import BodyCenteredCubic
from ase.constraints import StrainFilter
from ase.optimize import FIRE
from matscipy.elasticity import (measure_triclinic_elastic_constants,poisson_ratio)

a = BodyCenteredCubic(directions=[(1,0,0),(0,1,0), (0,0,1)], size=(1,1,1), symbol='Fe', pbc=True)
a.set_calculator(quippy.Potential('IP EAM_ErcolAd', param_filename='PotBH.xml'))
opt = FIRE(StrainFilter(a, mask=[1, 1, 1, 0, 0, 0]))
opt.run(fmax=1e-4)
a0 = a.get_cell()[0,0]

Ca = measure_triclinic_elastic_constants(a, optimizer=FIRE,
                        fmax=1e-4)

print(poisson_ratio(Ca, (1,0,0), (0,1,0)))
print(poisson_ratio(Ca, (0,1,1), (1,0,0)))

b = BodyCenteredCubic(directions=[(1,0,0),(0,1,1),(0,-1,1)],size=(1, 1, 1), symbol='Fe', pbc=True, latticeconstant=a0)
b.set_calculator(quippy.Potential('IP EAM_ErcolAd', param_filename='PotBH.xml'))
Cb = measure_triclinic_elastic_constants(b, delta=0.01,optimizer=FIRE,
                        fmax=1e-4)
print(poisson_ratio(Cb, (0,1,0), (1,0,0)))
